==> nuxeo-connect-update-6.1.0-sources.jar: org/nuxeo/connect/update/task/live/commands/UndeployConfig.java <==
/*
 * (C) Copyright 2006-2010 Nuxeo SAS (http://nuxeo.com/) and contributors.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser General Public License
 * (LGPL) version 2.1 which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl.html
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * Contributors:
 *     bstefanescu
 */
package org.nuxeo.connect.update.task.live.commands;

import java.io.File;
import java.util.Map;

import org.nuxeo.connect.update.PackageException;
import org.nuxeo.connect.update.task.Command;
import org.nuxeo.connect.update.task.Task;
import org.nuxeo.connect.update.task.standalone.commands.UndeployConfigPlaceholder;
import org.nuxeo.runtime.api.Framework;

/**
 * Undeploys runtime configuration files to the framework.
 * <p>
 * The inverse of this command is Deploy.
 *
 * @author <a href="mailto:bs@nuxeo.com">Bogdan Stefanescu</a>
 */
public class UndeployConfig extends UndeployConfigPlaceholder {

    public UndeployConfig() {
        super();
    }

    public UndeployConfig(File file) {
        super(file);
    }

    @Override
    protected Command doRun(Task task, Map<String, String> prefs)
            throws PackageException {
        try {
            Framework.getRuntime().getContext().undeploy(file.toURI().toURL());
        } catch (Exception e) {
            throw new PackageException("Failed to undeploy configuration file "
                    + file, e);
        }
        return new DeployConfig(file);
    }

}

==> nuxeo-connect-update-7.1-sources.jar: org/nuxeo/connect/update/task/live/commands/UndeployConfig.java <==
/*
 * (C) Copyright 2006-2010 Nuxeo SAS (http://nuxeo.com/) and contributors.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser General Public License
 * (LGPL) version 2.1 which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl.html
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * Contributors:
 *     bstefanescu
 */
package org.nuxeo.connect.update.task.live.commands;

import java.io.File;
import java.io.IOException;
import java.util.Map;

import org.nuxeo.connect.update.PackageException;
import org.nuxeo.connect.update.task.Command;
import org.nuxeo.connect.update.task.Task;
import org.nuxeo.connect.update.task.standalone.commands.UndeployConfigPlaceholder;
import org.nuxeo.runtime.api.Framework;

/**
 * Undeploys runtime configuration files to the framework.
 * <p>
 * The inverse of this command is Deploy.
 *
 * @author <a href="mailto:bs@nuxeo.com">Bogdan Stefanescu</a>
 */
public class UndeployConfig extends UndeployConfigPlaceholder {

    public UndeployConfig() {
        super();
    }

    public UndeployConfig(File file) {
        super(file);
    }

    @Override
    protected Command doRun(Task task, Map<String, String> prefs) throws PackageException {
        try {
            Framework.getRuntime().getContext().undeploy(file.toURI().toURL());
        } catch (IOException e) {
            throw new PackageException("Failed to undeploy configuration file " + file, e);
        }
        return new DeployConfig(file);
    }

}
